# Generated by Django 5.1.2 on 2024-11-18 19:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("fedj_webfinger", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="alias",
            name="value",
            field=models.CharField(max_length=512),
        ),
        migrations.AlterField(
            model_name="link",
            name="href",
            field=models.CharField(help_text="uri of link", max_length=512),
        ),
        migrations.AlterField(
            model_name="link",
            name="rel",
            field=models.CharField(
                help_text="relationship of link to subject", max_length=512
            ),
        ),
        migrations.AlterField(
            model_name="link",
            name="type",
            field=models.CharField(
                blank=True,
                help_text="The media type of the dereferenced link. http://www.iana.org/assignments/media-types/media-types.xhtml",
                max_length=512,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="linkproperty",
            name="value",
            field=models.CharField(max_length=512),
        ),
        migrations.AlterField(
            model_name="linktitle",
            name="value",
            field=models.CharField(max_length=512),
        ),
        migrations.AlterField(
            model_name="property",
            name="name",
            field=models.CharField(max_length=512, unique=True),
        ),
        migrations.AlterField(
            model_name="property",
            name="value",
            field=models.CharField(max_length=512, unique=True),
        ),
        migrations.AlterField(
            model_name="subject",
            name="value",
            field=models.CharField(max_length=512, unique=True, verbose_name="URI"),
        ),
    ]
