# Generated by Django 5.1.2 on 2024-11-18 21:33

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "fedj_webfinger",
            "0002_alter_alias_value_alter_link_href_alter_link_rel_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="linkproperty",
            name="name",
            field=models.CharField(max_length=32),
        ),
        migrations.AlterField(
            model_name="linktitle",
            name="link",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="titles",
                to="fedj_webfinger.link",
            ),
        ),
    ]
